@@ -36,9 +36,8 @@ class HomeAssistantCog(commands.Cog):
     @commands.has_role("Shiny")
     async def arm(self, context: discord.Interaction, choices: str):
         # print(await self.get_functions())
-        testing = ha.Alarm()
-        testing_function = getattr(testing, choices)
-        testing_function()
+        alarm = ha.Alarm()
+        getattr(alarm, choices)()
         await context.response.send_message(f"Testing is {choices}ing")
 
     @app_commands.command(name="taylor_swiftly")
@@ -46,10 +45,9 @@ class HomeAssistantCog(commands.Cog):
     @commands.has_role("Shiny")
     async def tesla(self, context: discord.Interaction, choices: str):
         # print(await self.get_functions())
-        testing = ha.Lock(entity_id="taylor_swiftly_doors", location="home")
-        testing_function = getattr(testing, choices)
-        testing_function()
-        await context.response.send_message(f"Testing is {choices}ing")
+        taylor = ha.Lock(entity_id="taylor_swiftly_doors", location="home")
+        status = getattr(taylor, choices)()
+        await context.response.send_message(f"Testing is {status}")
 
 
 async def setup(client: commands.Cog):
